*********
QBirthday
*********

QBirthday is a birthday reminder status icon.


Features
========

- Several backends available (CSV file, Lightning, MySQL databse).
- Extendable to other backends.
- iCalendar export.


Requirements
============

QBirthday runs on Python >= 3.8.

It requires PyQt5 and optionally depends on mysqlclient if a MySQL database is used as backend.


Installation
============

Either as root or in a Python virtual environment:
::

    $ pip install qbirthday

To use MySQL backend, install mysqlclient:
::

    $ pip install mysqlclient


History
=======

QBirthday is a Qt port of GBirthday, a GTK application.


Project links
=============

- PyPI: https://pypi.python.org/pypi/qbirthday
- Changelog: https://github.com/lafrech/qbirthday/blob/master/CHANGELOG.rst
- Issues: https://github.com/lafrech/qbirthday/issues


License
=======

QBirthday is distributed under GPLv2 license (see LICENSE file).
